@@ -46,6 +46,27 @@ class ParameterMixin(BaseModel):
             self.add_parameters(parameters=parameters)
         self.initialization_parameters = self.parameters.copy()
 
+    ##########################################################################
+    # Meta info
+    ##########################################################################
+
+    def _add_parameter_meta_info(self, parameter: str, meta_info: dict) -> None:
+        self.meta_info.setdefault("parameters", {}).setdefault(
+            parameter,
+            Parameter(**meta_info),  # type: ignore
+        )
+
+    def update_parameter_meta_info(self, parameter: str, meta_info: dict) -> None:
+        """Update meta info of a parameter.
+
+        Parameters
+        ----------
+        meta_info
+            Meta info of the parameter. Allowed keys are
+            {unit, database_links, notes}
+        """
+        self.update_meta_info(component="parameters", meta_info={parameter: meta_info})
+
     ##########################################################################
     # Parameter functions
     ##########################################################################
@@ -63,10 +84,7 @@ class ParameterMixin(BaseModel):
         """
         self._check_and_insert_ids([parameter_name], context="add_parameter")
         self.add_and_update_parameter(parameter_name, parameter_value)
-        self.meta_info.setdefault("parameters", {}).setdefault(
-            parameter_name,
-            Parameter(**meta_info),  # type: ignore
-        )
+        self._add_parameter_meta_info(parameter_name, meta_info)
 
     def add_parameters(
         self,
@@ -83,7 +101,12 @@ class ParameterMixin(BaseModel):
                 **info,
             )
 
-    def update_parameter(self, parameter_name: str, parameter_value: float) -> None:
+    def update_parameter(
+        self,
+        parameter_name: str,
+        parameter_value: float,
+        **meta_info: Dict[str, Any],
+    ) -> None:
         """Update an existing model parameter.
 
         Warns
@@ -94,20 +117,29 @@ class ParameterMixin(BaseModel):
         if parameter_name not in self.parameters:
             warnings.warn(f"Key {parameter_name} is not in the model. Adding.")
         self.add_and_update_parameter(parameter_name, parameter_value)
+        self.update_parameter_meta_info(parameter_name, meta_info)
 
     def scale_parameter(self, parameter_name: str, factor: float) -> None:
         self.parameters[parameter_name] *= factor
 
-    def update_parameters(self, parameters: Dict[str, float]) -> None:
+    def update_parameters(
+        self,
+        parameters: Dict[str, float],
+        meta_info: Dict[str, Dict[str, Any]] | None = None,
+    ) -> None:
         """Update multiple existing model parameters.
 
         See Also
         --------
         update_parameter
         """
+        meta_info = {} if meta_info is None else meta_info
         for parameter_name, parameter_value in parameters.items():
+            info = meta_info.get(parameter_name, {})
             self.update_parameter(
-                parameter_name=parameter_name, parameter_value=parameter_value
+                parameter_name=parameter_name,
+                parameter_value=parameter_value,
+                **info,
             )
 
     def add_and_update_parameter(
@@ -115,38 +147,41 @@ class ParameterMixin(BaseModel):
         parameter_name: str,
         parameter_value: float,
         update_derived: bool = True,
+        **meta_info: Dict[str, Any],
     ) -> None:
         """Add a new or update an existing parameter."""
         if parameter_name not in self._ids:
-            self._check_and_insert_ids([parameter_name], context="add_and_update_parameter")
+            self._check_and_insert_ids(
+                [parameter_name], context="add_and_update_parameter"
+            )
+            self._add_parameter_meta_info(parameter_name, meta_info)
+        else:
+            self.update_parameter_meta_info(parameter_name, meta_info)
 
         self.parameters[parameter_name] = parameter_value
         if parameter_name in self._derived_from_parameters and update_derived:
             self._update_derived_parameters()
 
-    def add_and_update_parameters(self, parameters: Dict[str, float]) -> None:
+    def add_and_update_parameters(
+        self,
+        parameters: Dict[str, float],
+        meta_info: Dict[str, Dict[str, Any]] | None = None,
+    ) -> None:
         """Add new and update existing model parameters.
 
         See Also
         --------
         add_and_update_parameter
         """
+        meta_info = {} if meta_info is None else meta_info
         for parameter_name, parameter_value in parameters.items():
+            info = meta_info.get(parameter_name, {})
             self.add_and_update_parameter(
-                parameter_name=parameter_name, parameter_value=parameter_value
+                parameter_name=parameter_name,
+                parameter_value=parameter_value,
+                **info,
             )
 
-    def update_parameter_meta_info(self, parameter: str, meta_info: dict) -> None:
-        """Update meta info of a parameter.
-
-        Parameters
-        ----------
-        meta_info
-            Meta info of the parameter. Allowed keys are
-            {unit, database_links, notes}
-        """
-        self.update_meta_info(component="parameters", meta_info={parameter: meta_info})
-
     def remove_parameter(self, parameter_name: str) -> None:
         """Remove a parameter from the model."""
         del self.parameters[parameter_name]
@@ -164,8 +199,16 @@ class ParameterMixin(BaseModel):
         for parameter_name in parameter_names:
             self.remove_parameter(parameter_name=parameter_name)
 
+    ##########################################################################
+    # Derived parameter functions
+    ##########################################################################
+
     def add_derived_parameter(
-        self, parameter_name: str, function: Callable, parameters: List[str]
+        self,
+        parameter_name: str,
+        function: Callable,
+        parameters: List[str],
+        **meta_info: Dict[str, Any],
     ) -> None:
         """Add a derived parameter.
 
@@ -188,10 +231,15 @@ class ParameterMixin(BaseModel):
         self.add_parameter(
             parameter_name=parameter_name,
             parameter_value=function(*parameter_values),
+            **meta_info,
         )
 
     def update_derived_parameter(
-        self, parameter_name: str, function: Callable | None, parameters: List[str] | None
+        self,
+        parameter_name: str,
+        function: Callable | None,
+        parameters: List[str] | None,
+        **meta_info: Dict[str, Any],
     ) -> None:
         old = self.derived_parameters[parameter_name]
         if function is None:
@@ -202,6 +250,7 @@ class ParameterMixin(BaseModel):
         self.derived_parameters[parameter_name]["function"] = function
         self.derived_parameters[parameter_name]["parameters"] = parameters
         self._update_derived_parameters()
+        self.update_parameter_meta_info(parameter_name, meta_info)
 
     def remove_derived_parameter(self, parameter_name: str) -> None:
         """Remove a derived parameter from the model."""
