@@ -2,15 +2,19 @@ from __future__ import annotations
 
 __all__ = [
     "Simulator",
+    "_AbstractRateModel",
+    "_AbstractStoichiometricModel",
     "_BaseRateSimulator",
     "_BaseSimulator",
     "_LabelSimulate",
     "_LinearLabelSimulate",
     "_Simulate",
+    "BASE_MODEL_TYPE",
+    "RATE_MODEL_TYPE",
 ]
 
 import warnings
-from typing import Dict, List, Optional, Type, Union, overload
+from typing import Dict, List, Type, Union, overload
 
 from ...typing import Array, ArrayLike
 from ..integrators import AbstractIntegrator, Scipy
