@@ -517,7 +517,12 @@ class _BaseRateSimulator(Generic[RATE_MODEL_TYPE], _BaseSimulator[RATE_MODEL_TYP
         if test_run:
             self._test_run()
 
-    def update_parameter(self, parameter_name: str, parameter_value: float) -> None:
+    def update_parameter(
+        self,
+        parameter_name: str,
+        parameter_value: float,
+        **meta_info: Dict[str, Any],
+    ) -> None:
         """Update a model parameter."""
         self.model.update_parameter(
             parameter_name=parameter_name, parameter_value=parameter_value
