@@ -11,7 +11,6 @@ from pathlib import Path
 from typing import Any, Dict, List, Optional, Tuple, Type, Union, cast
 
 import numpy as np
-import pandas as pd
 from matplotlib.figure import Figure
 from scipy.optimize import minimize
 
@@ -22,9 +21,6 @@ from ..integrators import AbstractIntegrator
 from ..models import Model
 from . import _BaseRateSimulator
 
-from mpl_toolkits.mplot3d import Axes3D as _Axes3D  # flake8: NOQA
-
-
 warnings.formatwarning = warning_on_one_line  # type: ignore
 
 
